--[[	Special Frames	]]--

local _G = _G
local pairs = pairs
local select = select
local tonumber = tonumber
local tostring = tostring

----------------------

local GetCVar = _G.GetCVar
local GetNumArenaOpponentSpecs = _G.GetNumArenaOpponentSpecs
local GetNumGroupMembers = _G.GetNumGroupMembers
local GetNumSubgroupMembers = _G.GetNumSubgroupMembers
local IsAddOnLoaded = _G.IsAddOnLoaded
local IsInInstance = _G.IsInInstance
local SetCVar = _G.SetCVar
local UnitExists = _G.UnitExists
local UnitInOtherParty = _G.UnitInOtherParty
local UnitInPhase = _G.UnitInPhase

----------------------

local addonName, ns = ...
local L = ns.L
local HideBlizzard = LibStub("AceAddon-3.0"):GetAddon(addonName)
SpecialFrames = HideBlizzard:NewModule("SpecialFrames")
local mod = SpecialFrames

----------------------

local dummy = function() end

local settings

local defaults = {
	profile = {
		["armoredman"] = nil,
		["aura"] = nil,
		["islandexpedition"] = nil,
		["minimap"] = nil,
		["mirrorbar"] = nil,
		["talkinghead"] = nil,
		["vehicleseat"] = nil,
		-- alerts
		["allalerts"] = nil,
		["boss"] = nil,
		["garrison"] = nil,
		["levelup"] = nil,
		-- messages
		["errormessage"] = nil,
		["infomessage"] = nil,
		["sysmessage"] = nil,
		["zonetext"] = nil,
		["subzonetext"] = nil,
		-- party/raid
		["bossframe"] = nil,
		["compactraid"] = nil,
		["party"] = nil,
		["phaseicon"] = nil,
		--tooltips
		["gametooltip"] = nil,
		["shoppingtooltip"] = nil,
	},
}

----------------------

local function out(msg)

	DEFAULT_CHAT_FRAME:AddMessage("|cffAEAEE0"..addonName..":|r "..msg)

end

local function debug(msg)

	local debug = false

	if ( debug ) then

		out(msg)

	end

end

----------------------

function mod:getOptions()

debug("SpecialFrames getOptions")

return {
	name = L["SpecialFrames"],
	type = "group",
	arg = "SpecialFrames",
	get = function(info)

		local key = info[#info]
		local v = settings[key]

		return v

	end,
	set = function(info, value)

		local key = info[#info]

		settings[key] = value

	end,
	args = {
		enabled = {
			name = "|cffFFFF55"..L["Enable Special Frames"].."|r",
			desc = "|cffFFFF55"..L["Hides various UI frames."].."|r",
			descStyle = "inline",
			type = "toggle",
			order = 1,
			width = "full",
			get = function() return HideBlizzard:GetModuleEnabled("SpecialFrames") end,
			set = function(info, value) HideBlizzard:SetModuleEnabled("SpecialFrames", value) end,
		},
		spacer = {
			name = "",
			type = "description",
			order = 1.5,
		},
		armoredman = {
			name = L["Armored Man"],
			desc = L["Hides the armored man ( durability ) under the minimap."],
			type = "toggle",
			order = 2,
			disabled = function() return not SpecialFrames:IsEnabled() end,
			set = function(info, v)

				settings.armoredman = v

				mod:UpdateArmoredMan()

			end,
		},
		aura = {
			name = L["Aura"],
			desc = L["Hides the buff / debuff frame."],
			type = "toggle",
			order = 3,
			disabled = function() return not SpecialFrames:IsEnabled() end,
			set = function(info, v)

				settings.aura = v

				mod:UpdateAura()

			end,
		},
		islandexpedition = {
			name = L["Island Expedition"],
			desc = L["Hides the island expedition frame at top of the screen."],
			order = 4,
			type = "toggle",
			disabled = function() return not SpecialFrames:IsEnabled() end,
			set = function(info, v)

				settings.islandexpedition = v

				mod:UpdateIslandExpedition()

			end,
		},
		minimap = {
			name = L["Minimap"],
			desc = L["Hides the minimap."],
			order = 5,
			type = "toggle",
			disabled = function() return not SpecialFrames:IsEnabled() end,
			set = function(info, v)

				settings.minimap = v

				mod:UpdateMinimap()

			end,
		},
		mirrorbar = {
			name = L["Mirror Bar"],
			desc = L["Hides the mirror ( breath/fatigue ) bar at top of screen."],
			order = 6,
			type = "toggle",
			disabled = function() return not SpecialFrames:IsEnabled() end,
			set = function(info, v)

				settings.mirrorbar = v

				mod:UpdateMirrorBar()

			end,
		},
		talkinghead = {
			name = L["Talking Head"],
			desc = L["Hides the talking head frame."],
			order = 7,
			type = "toggle",
			disabled = function() return not SpecialFrames:IsEnabled() end,
			set = function(info, v)

				settings.talkinghead = v

				mod:UpdateTalkingHead()

			end,
		},
		vehicleseat = {
			name = L["Vehicle Seat Indicator"],
			desc = L["Hides the vehicle seat indicator frame under the minimap."],
			order = 8,
			type = "toggle",
			disabled = function() return not SpecialFrames:IsEnabled() end,
			set = function(info, v)

				settings.vehicleseat = v

				mod:UpdateVehicleSeatIndicator()

			end,
		},
		alerts = {
			name = L["Alert Frames"],
			order = 9,
			type = "group",
			args = {
				allalerts = {
					name = L["All Alerts"],
					desc = L["Hides all alert windows."].."\n|cffFF6666"..L["Note: Will hide all alert frames."].."|r",
					order = 1,
					type = "toggle",
					disabled = function() return not SpecialFrames:IsEnabled() end,
					set = function(info, v)

						settings.allalerts = v

						mod:UpdateAllAlerts()

					end,
				},
				boss = {
					name = L["Boss Alert"],
					desc = L["Hides the boss alert window."],
					order = 2,
					type = "toggle",
					disabled = function() return ( not SpecialFrames:IsEnabled() or settings.allalerts ) end,
					set = function(info, v)

						settings.boss = v

						mod:UpdateBoss()

					end,
				},
				garrison = {
					name = L["Garrison Alert"],
					desc = L["Hides the garrison alert window."],
					order = 3,
					type = "toggle",
					disabled = function() return ( not SpecialFrames:IsEnabled() or settings.allalerts ) end,
					set = function(info, v)

						settings.garrison = v

						mod:UpdateGarrison()

					end,
				},
				levelup = {
					name = L["Level Up Alert"],
					desc = L["Hides the level up alert window."],
					order = 4,
					type = "toggle",
					disabled = function() return ( not SpecialFrames:IsEnabled() or settings.allalerts ) end,
					set = function(info, v)

						settings.levelup = v

						mod:UpdateLevelUp()

					end,
				},
			},
		},
		messages = {
			name = L["Messages"],
			order = 10,
			type = "group",
			args = {
				sysmessage = {
					name = L["System Message"],
					desc = L["Hides all the |cffFFFF00system message text|r at top of the screen."],
					order = 1,
					type = "toggle",
					disabled = function() return not SpecialFrames:IsEnabled() end,
					set = function(info, v)

						settings.sysmessage = v

						mod:UpdateSystemMessage()

					end,
				},
				infomessage = {
					name = L["Info Message"],
					desc = L["Hides all the |cffFFFF00notification text|r at top of the screen."],
					order = 2,
					type = "toggle",
					disabled = function() return not SpecialFrames:IsEnabled() end,
					set = function(info, v)

						settings.infomessage = v

						mod:UpdateInfoMessage()

					end,
				},
				errormessage = {
					name = L["Error Message"],
					desc = L["Hides all the |cffFF0000error text|r at top of the screen."],
					order = 3,
					type = "toggle",
					disabled = function() return not SpecialFrames:IsEnabled() end,
					set = function(info, v)

						settings.errormessage = v

						mod:UpdateErrorMessage()

					end,
				},
				subzonetext = {
					name = L["Subzone Text"],
					desc = L["Hides the subzone text in middle of the screen."],
					type = "toggle",
					order = 4,
					disabled = function() return not SpecialFrames:IsEnabled() end,
					set = function(info, v)

						settings.subzonetext = v

						mod:UpdateSubZoneText()

					end,
				},
				zonetext = {
					name = L["Zone Text"],
					desc = L["Hides the zone text in middle of the screen."],
					type = "toggle",
					order = 5,
					disabled = function() return not SpecialFrames:IsEnabled() end,
					set = function(info, v)

						settings.zonetext = v

						mod:UpdateZoneText()

					end,
				},
			},
		},
		partyopt = {
			name = L["Party/Raid"],
			order = 11,
			type = "group",
			args = {
				bossframe = {
					name = L["Boss Frame"],
					desc = L["Hides the boss frames under the minimap."],
					type = "toggle",
					order = 1,
					disabled = function() return not SpecialFrames:IsEnabled() end,
					set = function(info, v)

						settings.bossframe = v

						mod:UpdateBossFrame()

					end,
				},
				compactraid = {
					name = L["Compact Raid Frame"],
					desc = L["Hides the compact raid frame box on left side of screen."],
					order = 2,
					type = "toggle",
					disabled = function() return not SpecialFrames:IsEnabled() end,
					set = function(info, v)

						settings.compactraid = v

						mod:UpdateCompactRaid()

					end,
				},
				party = {
					name = L["Party Frame"],
					desc = L["Hides the party frame."],
					order = 3,
					type = "toggle",
					disabled = function() return not SpecialFrames:IsEnabled() end,
					set = function(info, v)

						settings.party = v

						mod:UpdateParty()

					end,
				},
				phaseicon = {
					name = L["Phasing Icon"],
					desc = L["Hides the phasing icon when in a party."],
					order = 4,
					type = "toggle",
					disabled = function() return not SpecialFrames:IsEnabled() end,
					set = function(info, v)

						settings.phaseicon = v

						mod:UpdatePhaseIcon()

					end,
				},
			},
		},
		tooltips = {
			name = L["Tooltips"],
			order = 12,
			type = "group",
			args = {
				gametooltip = {
					name = L["Game Tooltip"],
					desc = L["Hides the game tooltip frame."],
					order = 1,
					type = "toggle",
					disabled = function() return not SpecialFrames:IsEnabled() end,
					set = function(info, v)

						settings.gametooltip = v

						mod:UpdateGameTooltip()

					end,
				},
				shoppingtooltip = {
					name = L["Shopping Tooltips"],
					desc = L["Hides both the shopping tooltip frames."],
					order = 2,
					type = "toggle",
					disabled = function() return not SpecialFrames:IsEnabled() end,
					set = function(info, v)

						settings.shoppingtooltip = v

						mod:UpdateShoppingTooltip()

					end,
				},
			},
		},
	},
}
end

function mod:OnInitialize()

	debug("SpecialFrames OnInitialize")

	mod:SetEnabledState(HideBlizzard:GetModuleEnabled("SpecialFrames"))

	mod.db = HideBlizzard.db:RegisterNamespace("SpecialFrames", defaults)

	settings = mod.db.profile

	local options = mod:getOptions()

	HideBlizzard:RegisterModuleOptions("SpecialFrames", options, "SpecialFrames")

end

----------------------

function mod:OnEnable()

	debug("SpecialFrames OnEnable")

	mod:UpdateView()

end

----------------------

function mod:OnDisable()

	debug("SpecialFrames OnDisable")

	mod:UpdateView()

end

----------------------

function mod:UpdateView()

	debug("SpecialFrames UpdateView")

	mod:UpdateArmoredMan()
	mod:UpdateAura()
	mod:UpdateIslandExpedition()
	mod:UpdateMinimap()
	mod:UpdateMirrorBar()
	mod:UpdateTalkingHead()
	mod:UpdateVehicleSeatIndicator()

	mod:UpdateAllAlerts()
	mod:UpdateBoss()
	mod:UpdateGarrison()
	mod:UpdateLevelUp()

	mod:UpdateSystemMessage()
	mod:UpdateInfoMessage()
	mod:UpdateErrorMessage()
	mod:UpdateSubZoneText()
	mod:UpdateZoneText()

	mod:UpdateBossFrame()
	mod:UpdateCompactRaid()
	mod:UpdateParty()
	mod:UpdatePhaseIcon()

	mod:UpdateGameTooltip()
	mod:UpdateShoppingTooltip()

end

----------------------

function mod:UpdateAllAlerts()

	if ( settings.allalerts == nil ) then return end

	debug("UpdateAllAlerts")

	local AlertFrame = _G.AlertFrame

	if ( settings.allalerts and mod:IsEnabled() ) then

		hooksecurefunc(AlertFrame, "RegisterEvent", function(self, event)

			AlertFrame:UnregisterEvent(event)

		end)

		AlertFrame:UnregisterAllEvents()

	else

		hooksecurefunc(AlertFrame, "RegisterEvent", function(self, event)

			AlertFrame:RegisterEvent(event)

		end)

		AlertFrame:RegisterAllEvents()

		settings.allalerts = nil

	end

end

----------------------

function mod:UpdateArmoredMan()

	if ( settings.armoredman == nil ) then return end

	debug("UpdateArmoredMan")

	local DurabilityFrame = _G.DurabilityFrame

	if ( settings.armoredman and mod:IsEnabled() ) then

		DurabilityFrame:Hide()
		DurabilityFrame.Show = dummy

	else

		DurabilityFrame.Show = nil

		settings.armoredman = nil

	end

end

----------------------

function mod:UpdateAura()

	if ( settings.aura == nil ) then return end

	debug("UpdateAura")

	local BuffFrame = _G.BuffFrame
	local TemporaryEnchantFrame = _G.TemporaryEnchantFrame

	if ( settings.aura and mod:IsEnabled() ) then

		BuffFrame:Hide()
		BuffFrame.Show = dummy

		TemporaryEnchantFrame:Hide()
		TemporaryEnchantFrame.Show = dummy

	else

		BuffFrame.Show = nil
		BuffFrame:Show()

		TemporaryEnchantFrame.Show = nil
		TemporaryEnchantFrame:Show()

		settings.aura = nil

	end

end

----------------------

function mod:UpdateBoss()

	if ( settings.boss == nil ) then return end

	debug("UpdateBoss")

	if ( settings.boss and mod:IsEnabled() ) then

		BossBanner:UnregisterEvent("ENCOUNTER_LOOT_RECEIVED")
		BossBanner:UnregisterEvent("BOSS_KILL")

	else

		BossBanner:RegisterEvent("ENCOUNTER_LOOT_RECEIVED")
		BossBanner:RegisterEvent("BOSS_KILL")

		settings.boss = nil

	end

end

----------------------

function mod:UpdateBossFrame()

	if ( settings.bossframe == nil ) then return end

	debug("UpdateBossFrame")

	local function partyraidcheck()

		local a, b = IsInInstance()

		if ( a ) then

			if ( b == "raid" or b == "party" ) then

				return true

			end

		else

			return false

		end

	end

	if ( settings.bossframe and mod:IsEnabled() ) then

		for i=1, MAX_BOSS_FRAMES do

			if ( GetNumSubgroupMembers() > 0 ) then

				if ( partyraidcheck() ) then

					local bf = _G["Boss"..i.."TargetFrame"]

					if ( UnitExists(bf) ) then

						bf:Hide()
						bf.Show = dummy

					end

				end

			end

		end

	else

		for i=1, MAX_BOSS_FRAMES do

			if ( GetNumSubgroupMembers() > 0 ) then

				if ( partyraidcheck() ) then

					local bf = _G["Boss"..i.."TargetFrame"]

					if ( UnitExists(bf) ) then

						bf.Show = nil

					end

				end

			end

		end

		settings.bossframe = nil

	end

end

----------------------

function mod:UpdateCompactRaid()

	if ( settings.compactraid == nil ) then return end

	debug("UpdateCompactRaid")

	local CompactRaidFrame = _G.CompactRaidFrame

	local CompactRaidFrameManager = _G.CompactRaidFrameManager

	local CompactRaidFrameContainer = _G.CompactRaidFrameContainer

	if ( settings.compactraid and mod:IsEnabled() ) then

		if ( GetNumGroupMembers() > 0 ) then

			CompactRaidFrameManager:Hide()
			CompactRaidFrameManager.Show = dummy

			CompactRaidFrameContainer:SetParent(UIParent)

		else

			CompactRaidFrameManager:Hide()
			CompactRaidFrameManager.Show = dummy

			CompactRaidFrameContainer:SetParent(UIParent)

		end

	else

		if ( GetNumGroupMembers() > 0 ) then

			CompactRaidFrameManager.Show = nil
			CompactRaidFrameManager:Show()

			CompactRaidFrameContainer:SetParent(CompactRaidFrame)

		end

		settings.compactraid = nil

	end

end

----------------------

function mod:UpdateGarrison()

	if ( settings.garrison == nil ) then return end

	debug("UpdateGarrison")

	if ( settings.garrison and mod:IsEnabled() ) then

		AlertFrame:UnregisterEvent("GARRISON_MISSION_FINISHED")

	else

		AlertFrame:RegisterEvent("GARRISON_MISSION_FINISHED")

		settings.garrison = nil

	end

end
----------------------

function mod:UpdateGameTooltip()

	if ( settings.gametooltip == nil ) then return end

	debug("UpdateGameTooltip")

	local GameTooltip = _G.GameTooltip

	if ( settings.gametooltip and mod:IsEnabled() ) then

		GameTooltip:SetScript("OnShow", GameTooltip.Hide)

	else

		GameTooltip:SetScript("OnShow", GameTooltip.Show)

		settings.gametooltip = nil

	end

end

----------------------

function mod:UpdateIslandExpedition()

	if ( settings.islandexpedition == nil ) then return end

	debug("UpdateIslandExpedition")

	local UIWidgetTopCenterContainerFrame = _G.UIWidgetTopCenterContainerFrame

	if ( settings.islandexpedition and mod:IsEnabled() ) then

		if ( UIWidgetTopCenterContainerFrame ) then

			UIWidgetTopCenterContainerFrame:Hide()
			UIWidgetTopCenterContainerFrame.Show = dummy

		end

	else

		if ( UIWidgetTopCenterContainerFrame ) then

			UIWidgetTopCenterContainerFrame.Show = nil
			UIWidgetTopCenterContainerFrame:Show()

		end

		settings.islandexpedition = nil

	end

end

----------------------

function mod:UpdateLevelUp()

	if ( settings.levelup == nil ) then return end

	debug("UpdateLevelUp")

	if ( settings.levelup and mod:IsEnabled() ) then

		hooksecurefunc(LevelUpDisplay, "Show", LevelUpDisplay.Hide)

	else

		LevelUpDisplay.Show = nil

		local e = CreateFrame("Frame")
		e:RegisterEvent("PLAYER_LEVEL_UP")
		e:SetScript("OnEvent", function()

			if ( arg1 ) then

				LevelUpDisplay:Show()

			end

		end)

		settings.levelup = nil

	end

end

----------------------

function mod:UpdateMinimap()

	if ( settings.minimap == nil ) then return end

	debug("UpdateMinimap")

	local MinimapCluster = _G.MinimapCluster

	if ( settings.minimap and mod:IsEnabled() ) then

		MinimapCluster:Hide()
		MinimapCluster.Show = dummy
		MinimapCluster:EnableMouse(false)

	else

		MinimapCluster.Show = nil
		MinimapCluster:Show()
		MinimapCluster:EnableMouse(true)

		settings.minimap = nil

	end

end

----------------------

function mod:UpdateMirrorBar()

	if ( settings.mirrorbar == nil ) then return end

	debug("UpdateMirrorBar")

	local mbar = _G.MirrorTimer1

	if ( settings.mirrorbar and mod:IsEnabled() ) then

		if ( mbar ) then

			mbar:Hide()
			mbar.Show = dummy
			mbar:UnregisterAllEvents()

		else

			mbar:Hide()
			mbar.Show = dummy
			mbar:UnregisterAllEvents()

		end

	else

		mbar.Show = nil
		mbar:RegisterAllEvents()

		settings.mirrorbar = nil

	end

end

----------------------

function mod:UpdateParty()

	if ( settings.party == nil ) then return end

	debug("UpdateParty")

	local isCompact = tonumber(GetCVar("useCompactPartyFrames"))

	if ( settings.party and mod:IsEnabled() ) then

		for i=1, MAX_PARTY_MEMBERS do

			if ( GetNumSubgroupMembers(i) ) then

				if ( isCompact == 0 ) then

					local pf = _G["PartyMemberFrame"..i]

					pf:Hide()
					pf.Show = dummy

				end

			end

		end

	else

		for i=1, MAX_PARTY_MEMBERS do

			if ( GetNumSubgroupMembers(i) ) then

				if ( isCompact == 0 ) then

					local pf = _G["PartyMemberFrame"..i]

					pf.Show = nil

					if ( UnitExists("party"..i) ) then

						pf:Show()

					end

				end

			end

		end

		settings.party = nil

	end

end

----------------------

function mod:UpdatePhaseIcon()

	if ( settings.phaseicon == nil ) then return end

	debug("UpdatePhaseIcon")

	if ( settings.phaseicon and mod:IsEnabled() ) then

		for i=1, MAX_PARTY_MEMBERS do

			local icon = _G["PartyMemberFrame"..i.."NotPresentIcon"]
			local p = "party"..i
			local phase = UnitInPhase(p)
			local o,i = UnitInOtherParty(p)

			if ( not i ) then

				icon.Show = nil
				icon:Hide()

			elseif ( not i and UnitExists(p) ) then

				icon.Show = nil
				icon:Hide()

			else

				icon:Hide()

			end

		end

	else

		local isCompact = tonumber(GetCVar("useCompactPartyFrames"))

		for i=1, MAX_PARTY_MEMBERS do

			if ( GetNumSubgroupMembers(i) ) then

				if ( isCompact == 0 ) then

					local icon = _G["PartyMemberFrame"..i.."NotPresentIcon"]
					local p = "party"..i
					local phase = UnitInPhase(p)
					local o,i = UnitInOtherParty(p)

					if ( not i ) then

						icon.Show = nil
						icon:Show()

					elseif ( not i and UnitExists(p) ) then

						icon.Show = nil
						icon:Show()

					else

						icon:Hide()

					end

				end

			end

		end

		settings.phaseicon = nil

	end

end

----------------------

function mod:UpdateTalkingHead()

	if ( settings.talkinghead == nil ) then return end

	debug("UpdateTalkingHead")

	if ( settings.talkinghead and mod:IsEnabled() ) then

		if ( not IsAddOnLoaded("Blizzard_TalkingHeadUI") ) then

			LoadAddOn("Blizzard_TalkingHeadUI")

		end

		hooksecurefunc("TalkingHeadFrame_PlayCurrent", function()

			TalkingHeadFrame:Hide()

		end)

	else

		hooksecurefunc("TalkingHeadFrame_PlayCurrent", function()

			TalkingHeadFrame:Show()

		end)

		settings.talkinghead = nil

	end

end

----------------------

function mod:UpdateVehicleSeatIndicator()

	if ( settings.vehicleseat == nil ) then return end

	debug("UpdateVehicleSeatIndicator")

	local VehicleSeatIndicator = _G.VehicleSeatIndicator

	if ( settings.vehicleseat and mod:IsEnabled() ) then

		if ( VehicleSeatIndicator ) then

			VehicleSeatIndicator:Hide()
			VehicleSeatIndicator.Show = dummy

		end

	else

		VehicleSeatIndicator.Show = nil

		if ( VehicleSeatIndicator ) then

			VehicleSeatIndicator:Show()

		end

		settings.vehicleseat = nil

	end

end

----------------------

function mod:UpdateShoppingTooltip()

	if ( settings.shoppingtooltip == nil ) then return end

	debug("UpdateShoppingTooltip")

	local ShoppingTooltip1 = _G.ShoppingTooltip1

	local ShoppingTooltip2 = _G.ShoppingTooltip2

	if ( settings.shoppingtooltip and mod:IsEnabled() ) then

		ShoppingTooltip1:SetScript("OnShow", ShoppingTooltip1.Hide)
		ShoppingTooltip2:SetScript("OnShow", ShoppingTooltip2.Hide)

	else

		ShoppingTooltip1:SetScript("OnShow", ShoppingTooltip1.Show)
		ShoppingTooltip2:SetScript("OnShow", ShoppingTooltip2.Show)

		settings.shoppingtooltip = nil

	end

end

----------------------

function mod:UpdateSystemMessage()

	if ( settings.sysmessage == nil ) then return end

	debug("UpdateSystemMessage")

	local UIErrorsFrame = _G.UIErrorsFrame

	if ( settings.sysmessage and mod:IsEnabled() ) then

		UIErrorsFrame:UnregisterEvent("SYSMSG")

	else

		UIErrorsFrame:RegisterEvent("SYSMSG")

		settings.sysmessage = nil

	end

end

----------------------

function mod:UpdateInfoMessage()

	if ( settings.infomessage == nil ) then return end

	debug("UpdateInfoMessage")

	local UIErrorsFrame = _G.UIErrorsFrame

	if ( settings.infomessage and mod:IsEnabled() ) then

		UIErrorsFrame:UnregisterEvent("UI_INFO_MESSAGE")

	else

		UIErrorsFrame:RegisterEvent("UI_INFO_MESSAGE")

		settings.infomessage = nil

	end

end

----------------------

function mod:UpdateErrorMessage()

	if ( settings.errormessage == nil ) then return end

	debug("UpdateErrorMessage")

	local UIErrorsFrame = _G.UIErrorsFrame

	if ( settings.errormessage and mod:IsEnabled() ) then

		UIErrorsFrame:UnregisterEvent("UI_ERROR_MESSAGE")

	else

		UIErrorsFrame:RegisterEvent("UI_ERROR_MESSAGE")

		settings.errormessage = nil

	end

end

----------------------

function mod:UpdateSubZoneText()

	if ( settings.subzonetext == nil ) then return end

	debug("UpdateSubZoneText")

	local SubZoneTextFrame = _G.SubZoneTextFrame

	if ( settings.subzonetext and mod:IsEnabled() ) then

		SubZoneTextFrame:Hide()
		SubZoneTextFrame.Show = dummy

	else

		SubZoneTextFrame.Show = nil

		settings.subzonetext = nil

	end

end

----------------------

function mod:UpdateZoneText()

	if ( settings.zonetext == nil ) then return end

	debug("UpdateZoneText")

	local ZoneTextFrame = _G.ZoneTextFrame

	if ( settings.zonetext and mod:IsEnabled() ) then

		ZoneTextFrame:Hide()
		ZoneTextFrame.Show = dummy

	else

		ZoneTextFrame.Show = nil

		settings.zonetext = nil

	end

end
